==> react-nlp-annotate-0.1.17.tgz: package/components/Transcriber/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useEffect } from "react";
import EditableDocument from "../EditableDocument";
export default (function (_ref) {
  var initialTranscriptionText = _ref.initialTranscriptionText,
      onChange = _ref.onChange,
      audio = _ref.audio,
      phraseBankParam = _ref.phraseBank,
      validator = _ref.validator;

  var _useState = useState(window.localStorage.NLP_ANNOTATOR_AUTOPLAY === "true"),
      _useState2 = _slicedToArray(_useState, 2),
      autoPlayStatus = _useState2[0],
      changeAutoPlayStatus = _useState2[1]; // TODO create hook for usePhraseBank


  var _useState3 = useState(undefined),
      _useState4 = _slicedToArray(_useState3, 2),
      phraseBank = _useState4[0],
      changePhraseBank = _useState4[1];

  useEffect(function () {
    function loadPhraseBank() {
      return _loadPhraseBank.apply(this, arguments);
    }

    function _loadPhraseBank() {
      _loadPhraseBank = _asyncToGenerator(
      /*#__PURE__*/
      _regeneratorRuntime.mark(function _callee() {
        var fullPhraseBank, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, url, found, saveName, urlPhrases;

        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                if (typeof phraseBankParam === "string") {
                  phraseBankParam = [phraseBankParam];
                }

                if (!(Array.isArray(phraseBankParam) && phraseBankParam.every(function (p) {
                  return p.startsWith("http") && (p.endsWith(".txt") || p.endsWith(".csv"));
                }))) {
                  _context.next = 40;
                  break;
                }

                fullPhraseBank = [];
                _iteratorNormalCompletion = true;
                _didIteratorError = false;
                _iteratorError = undefined;
                _context.prev = 6;
                _iterator = phraseBankParam[Symbol.iterator]();

              case 8:
                if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
                  _context.next = 23;
                  break;
                }

                url = _step.value;
                found = void 0;
                saveName = "NLP_ANNOTATOR_PHRASE_BANK_".concat(url);

                if (window.localStorage[saveName]) {
                  try {
                    fullPhraseBank.push.apply(fullPhraseBank, _toConsumableArray(JSON.parse(window.localStorage[saveName])));
                    found = true;
                  } catch (e) {}
                }

                if (found) {
                  _context.next = 20;
                  break;
                }

                _context.next = 16;
                return fetch(url).then(function (res) {
                  return res.text();
                });

              case 16:
                _context.t0 = function (a) {
                  return a.trim().toLowerCase();
                };

                urlPhrases = _context.sent.split("\n").map(_context.t0);
                window.localStorage[saveName] = JSON.stringify(urlPhrases);
                fullPhraseBank.push.apply(fullPhraseBank, _toConsumableArray(urlPhrases));

              case 20:
                _iteratorNormalCompletion = true;
                _context.next = 8;
                break;

              case 23:
                _context.next = 29;
                break;

              case 25:
                _context.prev = 25;
                _context.t1 = _context["catch"](6);
                _didIteratorError = true;
                _iteratorError = _context.t1;

              case 29:
                _context.prev = 29;
                _context.prev = 30;

                if (!_iteratorNormalCompletion && _iterator.return != null) {
                  _iterator.return();
                }

              case 32:
                _context.prev = 32;

                if (!_didIteratorError) {
                  _context.next = 35;
                  break;
                }

                throw _iteratorError;

              case 35:
                return _context.finish(32);

              case 36:
                return _context.finish(29);

              case 37:
                changePhraseBank(fullPhraseBank);
                _context.next = 41;
                break;

              case 40:
                if (Array.isArray(phraseBankParam)) {
                  changePhraseBank(phraseBankParam);
                }

              case 41:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, null, [[6, 25, 29, 37], [30,, 32, 36]]);
      }));
      return _loadPhraseBank.apply(this, arguments);
    }

    loadPhraseBank();
    return function () {};
  }, [phraseBankParam]);
  return React.createElement("div", null, React.createElement("div", {
    style: {
      textAlign: "center",
      padding: 10
    }
  }, React.createElement("audio", {
    autoPlay: autoPlayStatus,
    loop: true,
    controlsList: "nodownload",
    controls: true
  }, React.createElement("source", {
    src: audio
  })), React.createElement("span", {
    style: {
      fontSize: 12
    }
  }, "Autoplay:", " ", React.createElement("input", {
    checked: autoPlayStatus,
    type: "checkbox",
    onChange: function onChange() {
      window.localStorage.NLP_ANNOTATOR_AUTOPLAY = JSON.stringify(window.localStorage.NLP_ANNOTATOR_AUTOPLAY !== "true");
      changeAutoPlayStatus(JSON.parse(window.localStorage.NLP_ANNOTATOR_AUTOPLAY));
    }
  }))), React.createElement("div", {
    style: {
      padding: 10
    }
  }, React.createElement(EditableDocument, {
    phraseBank: phraseBank,
    validator: validator,
    onChange: onChange,
    initialText: initialTranscriptionText
  })));
});

==> react-nlp-annotate-0.1.21.tgz: package/components/Transcriber/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useEffect } from "react";
import EditableDocument from "../EditableDocument";
export default (function (_ref) {
  var initialTranscriptionText = _ref.initialTranscriptionText,
      onChange = _ref.onChange,
      audio = _ref.audio,
      lowerCaseMode = _ref.lowerCaseMode,
      phraseBankParam = _ref.phraseBank,
      validator = _ref.validator;

  var _useState = useState(window.localStorage.NLP_ANNOTATOR_AUTOPLAY === "true"),
      _useState2 = _slicedToArray(_useState, 2),
      autoPlayStatus = _useState2[0],
      changeAutoPlayStatus = _useState2[1]; // TODO create hook for usePhraseBank


  var _useState3 = useState(undefined),
      _useState4 = _slicedToArray(_useState3, 2),
      phraseBank = _useState4[0],
      changePhraseBank = _useState4[1];

  useEffect(function () {
    function loadPhraseBank() {
      return _loadPhraseBank.apply(this, arguments);
    }

    function _loadPhraseBank() {
      _loadPhraseBank = _asyncToGenerator(
      /*#__PURE__*/
      _regeneratorRuntime.mark(function _callee() {
        var fullPhraseBank, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, url, found, saveName, _fullPhraseBank, _fullPhraseBank2, urlPhrases;

        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                if (typeof phraseBankParam === "string") {
                  phraseBankParam = [phraseBankParam];
                }

                if (!(Array.isArray(phraseBankParam) && phraseBankParam.every(function (p) {
                  return p.startsWith("http") && (p.endsWith(".txt") || p.endsWith(".csv"));
                }))) {
                  _context.next = 40;
                  break;
                }

                fullPhraseBank = [];
                _iteratorNormalCompletion = true;
                _didIteratorError = false;
                _iteratorError = undefined;
                _context.prev = 6;
                _iterator = phraseBankParam[Symbol.iterator]();

              case 8:
                if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
                  _context.next = 22;
                  break;
                }

                url = _step.value;
                found = void 0;
                saveName = "NLP_ANNOTATOR_PHRASE_BANK_".concat(url);

                if (window.localStorage[saveName]) {
                  try {
                    (_fullPhraseBank = fullPhraseBank).push.apply(_fullPhraseBank, _toConsumableArray(JSON.parse(window.localStorage[saveName])));

                    found = true;
                  } catch (e) {}
                }

                if (found) {
                  _context.next = 19;
                  break;
                }

                _context.next = 16;
                return fetch(url).then(function (res) {
                  return res.text();
                });

              case 16:
                urlPhrases = _context.sent.split("\n");
                window.localStorage[saveName] = JSON.stringify(urlPhrases);

                (_fullPhraseBank2 = fullPhraseBank).push.apply(_fullPhraseBank2, _toConsumableArray(urlPhrases));

              case 19:
                _iteratorNormalCompletion = true;
                _context.next = 8;
                break;

              case 22:
                _context.next = 28;
                break;

              case 24:
                _context.prev = 24;
                _context.t0 = _context["catch"](6);
                _didIteratorError = true;
                _iteratorError = _context.t0;

              case 28:
                _context.prev = 28;
                _context.prev = 29;

                if (!_iteratorNormalCompletion && _iterator.return != null) {
                  _iterator.return();
                }

              case 31:
                _context.prev = 31;

                if (!_didIteratorError) {
                  _context.next = 34;
                  break;
                }

                throw _iteratorError;

              case 34:
                return _context.finish(31);

              case 35:
                return _context.finish(28);

              case 36:
                if (lowerCaseMode) {
                  fullPhraseBank = fullPhraseBank.map(function (a) {
                    return a.toLowerCase();
                  });
                }

                changePhraseBank(fullPhraseBank);
                _context.next = 41;
                break;

              case 40:
                if (Array.isArray(phraseBankParam)) {
                  changePhraseBank(phraseBankParam);
                }

              case 41:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, null, [[6, 24, 28, 36], [29,, 31, 35]]);
      }));
      return _loadPhraseBank.apply(this, arguments);
    }

    loadPhraseBank();
    return function () {};
  }, [phraseBankParam]);
  return React.createElement("div", null, React.createElement("div", {
    style: {
      textAlign: "center",
      padding: 10
    }
  }, React.createElement("audio", {
    autoPlay: autoPlayStatus,
    loop: true,
    controlsList: "nodownload",
    controls: true
  }, React.createElement("source", {
    src: audio
  })), React.createElement("span", {
    style: {
      fontSize: 12
    }
  }, "Autoplay:", " ", React.createElement("input", {
    checked: autoPlayStatus,
    type: "checkbox",
    onChange: function onChange() {
      window.localStorage.NLP_ANNOTATOR_AUTOPLAY = JSON.stringify(window.localStorage.NLP_ANNOTATOR_AUTOPLAY !== "true");
      changeAutoPlayStatus(JSON.parse(window.localStorage.NLP_ANNOTATOR_AUTOPLAY));
    }
  }))), React.createElement("div", {
    style: {
      padding: 10
    }
  }, React.createElement(EditableDocument, {
    phraseBank: phraseBank,
    validator: validator,
    onChange: onChange,
    initialText: initialTranscriptionText
  })));
});
